@@ -21,12 +21,18 @@ sub has_section {
 
 sub get_section {
     my ($self, $key) = @_;
-    return $self->{_value_map}->{$key};
+    my $value = $self->{_value_map}->{$key};
+    return wantarray ? @$value : $value->[0];
 }
 
 sub get_sections {
     my ($self, $key) = @_;
-    map { $self->{_value_map}->{$_} } @{$self->{_section_order}};
+    map { $self->{_value_map}->{$_} } $self->get_section_names();
+}
+
+sub get_section_names {
+    my ($self, $key) = @_;
+    @{$self->{_section_order}};
 }
 
 sub get_filter {
@@ -37,10 +43,15 @@ sub get_filter {
 sub push_section {
     my ($self, $key, $value, $filters) = @_;
     $self->{_filter_map}->{$key} = $filters;
-    $self->{_value_map}->{$key} = $value;
+    $self->{_value_map}->{$key} = [$value];
     push @{$self->{_section_order}}, $key;
 }
 
+sub set_section {
+    my ($self, $key, @values) = @_;
+    $self->{_value_map}->{$key} = [@values];
+}
+
 our $AUTOLOAD;
 sub AUTOLOAD {
     $AUTOLOAD =~ s/.*:://;
